@@ -19,15 +19,15 @@ class PropertyDelegate : public KWidgetItemDelegate
     Q_OBJECT
 public:
     explicit PropertyDelegate(QAbstractItemView *parent);
-    virtual ~PropertyDelegate();
+    ~PropertyDelegate() override;
     /** reimplemented from QAbstractItemDelegate **/
-    virtual void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE;
+    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
     /** reimplemented fromKWidgetItemDelegate **/
-    virtual QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const Q_DECL_OVERRIDE;
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const override;
     /** reimplemented fromKWidgetItemDelegate **/
-    virtual QList<QWidget*> createItemWidgets(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QList<QWidget*> createItemWidgets(const QModelIndex &index) const override;
     /** reimplemented fromKWidgetItemDelegate **/
-    virtual void updateItemWidgets(const QList<QWidget*> widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const Q_DECL_OVERRIDE;
+    void updateItemWidgets(const QList<QWidget*> widgets, const QStyleOptionViewItem& option, const QPersistentModelIndex& index) const override;
 
 private Q_SLOTS:
     void onNameEditingFinished();
