@@ -18,8 +18,8 @@ class TransformEdgesWidget : public QDialog
     Q_OBJECT
 
 public:
-    explicit TransformEdgesWidget(GraphDocumentPtr document, QWidget *parent = 0);
-    ~TransformEdgesWidget();
+    explicit TransformEdgesWidget(GraphDocumentPtr document, QWidget *parent = nullptr);
+    ~TransformEdgesWidget() override;
 
 public Q_SLOTS:
     void transform();
