@@ -1,21 +1,7 @@
 /*
- *  Copyright 2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "nodewrapper.h"
@@ -112,7 +98,8 @@ void NodeWrapper::setType(int typeId)
     if (newType->id() == typeId) {
         return;
     }
-    for (const auto &type : m_node->document()->nodeTypes()) {
+    const auto nodeTypes = m_node->document()->nodeTypes();
+    for (const auto &type : nodeTypes) {
         if (type->id() == typeId) {
             newType = type;
             break;
@@ -120,7 +107,7 @@ void NodeWrapper::setType(int typeId)
     }
     if (newType == m_node->type()) {
         QString command = QString("node.type = %1)").arg(typeId);
-        emit message(i18nc("@info:shell", "%1: node type ID %2 not registered", command, typeId), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: node type ID %2 not registered", command, typeId), Kernel::ErrorMessage);
         return;
     }
     m_node->setType(newType);
@@ -130,7 +117,8 @@ void NodeWrapper::setType(int typeId)
 QList<GraphTheory::EdgeWrapper*> NodeWrapper::edges() const
 {
     QList<EdgeWrapper*> edges;
-    for (const auto &edge : m_node->edges()) {
+    const auto nodeEdges = m_node->edges();
+    for (const auto &edge : nodeEdges) {
         edges.append(m_documentWrapper->edgeWrapper(edge));
     }
     return edges;
@@ -139,7 +127,8 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::edges() const
 QList<GraphTheory::EdgeWrapper*> NodeWrapper::edges(int type) const
 {
     EdgeTypePtr typePtr;
-    for (const auto &typeTest : m_node->document()->edgeTypes()) {
+    const auto edgeTypes = m_node->document()->edgeTypes();
+    for (const auto &typeTest : edgeTypes) {
         if (typeTest->id() == type) {
             typePtr = typeTest;
             break;
@@ -147,11 +136,12 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::edges(int type) const
     }
     if (!typePtr) {
         QString command = QString("node.edges(%1)").arg(type);
-        emit message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
         return QList<EdgeWrapper*>();
     }
     QList<EdgeWrapper*> edges;
-    for (const auto &edge : m_node->edges(typePtr)) {
+    const auto nodeEges = m_node->edges(typePtr);
+    for (const auto &edge : nodeEges) {
         edges.append(m_documentWrapper->edgeWrapper(edge));
     }
     return edges;
@@ -160,7 +150,8 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::edges(int type) const
 QList<GraphTheory::EdgeWrapper*> NodeWrapper::inEdges() const
 {
     QList<EdgeWrapper*> edges;
-    for (const auto &edge : m_node->inEdges()) {
+    const auto inEdges = m_node->inEdges();
+    for (const auto &edge : inEdges) {
         edges.append(m_documentWrapper->edgeWrapper(edge));
     }
     return edges;
@@ -169,7 +160,8 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::inEdges() const
 QList<GraphTheory::EdgeWrapper*> NodeWrapper::inEdges(int type) const
 {
     EdgeTypePtr typePtr;
-    for (const auto &typeTest : m_node->document()->edgeTypes()) {
+    const auto edgeTypes = m_node->document()->edgeTypes();
+    for (const auto &typeTest : edgeTypes) {
         if (typeTest->id() == type) {
             typePtr = typeTest;
             break;
@@ -177,11 +169,12 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::inEdges(int type) const
     }
     if (!typePtr) {;
         QString command = QString("node.inEdges(%1)").arg(type);
-        emit message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
         return QList<EdgeWrapper*>();
     }
     QList<EdgeWrapper*> edges;
-    for (const auto &edge : m_node->inEdges(typePtr)) {
+    const auto inEdges = m_node->inEdges(typePtr);
+    for (const auto &edge : inEdges) {
         edges.append(m_documentWrapper->edgeWrapper(edge));
     }
     return edges;
@@ -190,7 +183,8 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::inEdges(int type) const
 QList<GraphTheory::EdgeWrapper*> NodeWrapper::outEdges() const
 {
     QList<EdgeWrapper*> edges;
-    for (const auto &edge : m_node->outEdges()) {
+    const auto outEdges = m_node->outEdges();
+    for (const auto &edge : outEdges) {
         edges.append(m_documentWrapper->edgeWrapper(edge));
     }
     return edges;
@@ -199,7 +193,8 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::outEdges() const
 QList<GraphTheory::EdgeWrapper*> NodeWrapper::outEdges(int type) const
 {
     EdgeTypePtr typePtr;
-    for (const auto &typeTest : m_node->document()->edgeTypes()) {
+    const auto edgeTypes = m_node->document()->edgeTypes();
+    for (const auto &typeTest : edgeTypes) {
         if (typeTest->id() == type) {
             typePtr = typeTest;
             break;
@@ -207,11 +202,12 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::outEdges(int type) const
     }
     if (!typePtr) {
         QString command = QString("node.outEdges(%1)").arg(type);
-        emit message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
         return QList<EdgeWrapper*>();
     }
     QList<EdgeWrapper*> edges;
-    for (const auto &edge : m_node->outEdges(typePtr)) {
+    const auto outEdges = m_node->outEdges(typePtr);
+    for (const auto &edge : outEdges) {
         edges.append(m_documentWrapper->edgeWrapper(edge));
     }
     return edges;
@@ -220,7 +216,8 @@ QList<GraphTheory::EdgeWrapper*> NodeWrapper::outEdges(int type) const
 QList<NodeWrapper*> NodeWrapper::neighbors() const
 {
     QSet<NodeWrapper*> neighbors;
-    for (const auto &edge : m_node->edges()) {
+    const auto edges = m_node->edges();
+    for (const auto &edge : edges) {
         if (m_node == edge->from()) {
             neighbors.insert(m_documentWrapper->nodeWrapper(edge->to()));
         } else {
@@ -233,7 +230,8 @@ QList<NodeWrapper*> NodeWrapper::neighbors() const
 QList<NodeWrapper*> NodeWrapper::neighbors(int type) const
 {
     EdgeTypePtr typePtr;
-    for (const auto &typeTest : m_node->document()->edgeTypes()) {
+    const auto edgeTypes = m_node->document()->edgeTypes();
+    for (const auto &typeTest : edgeTypes) {
         if (typeTest->id() == type) {
             typePtr = typeTest;
             break;
@@ -241,11 +239,12 @@ QList<NodeWrapper*> NodeWrapper::neighbors(int type) const
     }
     if (!typePtr) {
         QString command = QString("node.neighbors(%1)").arg(type);
-        emit message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
         return QList<NodeWrapper*>();
     }
     QSet<NodeWrapper*> neighbors;
-    for (const auto &edge : m_node->edges(typePtr)) {
+    const auto edges = m_node->edges(typePtr);
+    for (const auto &edge : edges) {
         if (m_node == edge->from()) {
             neighbors.insert(m_documentWrapper->nodeWrapper(edge->to()));
         } else {
@@ -258,7 +257,8 @@ QList<NodeWrapper*> NodeWrapper::neighbors(int type) const
 QList<NodeWrapper*> NodeWrapper::predecessors() const
 {
     QSet<NodeWrapper*> precessors;
-    for (const auto &edge : m_node->inEdges()) {
+    const auto inEdges = m_node->inEdges();
+    for (const auto &edge : inEdges) {
         if (edge->type()->direction() == EdgeType::Unidirectional) {
             precessors.insert(m_documentWrapper->nodeWrapper(edge->from()));
             continue;
@@ -276,7 +276,8 @@ QList<NodeWrapper*> NodeWrapper::predecessors() const
 QList<NodeWrapper*> NodeWrapper::predecessors(int type) const
 {
     EdgeTypePtr typePtr;
-    for (const auto &typeTest : m_node->document()->edgeTypes()) {
+    const auto edgeTypes = m_node->document()->edgeTypes();
+    for (const auto &typeTest : edgeTypes) {
         if (typeTest->id() == type) {
             typePtr = typeTest;
             break;
@@ -284,11 +285,12 @@ QList<NodeWrapper*> NodeWrapper::predecessors(int type) const
     }
     if (!typePtr) {
         QString command = QString("node.predecessors(%1)").arg(type);
-        emit message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
         return QList<NodeWrapper*>();
     }
     QSet<NodeWrapper*> precessors;
-    for (const auto &edge : m_node->inEdges(typePtr)) {
+    const auto inEdges = m_node->inEdges(typePtr);
+    for (const auto &edge : inEdges) {
         if (edge->type()->direction() == EdgeType::Unidirectional) {
             precessors.insert(m_documentWrapper->nodeWrapper(edge->from()));
             continue;
@@ -306,7 +308,8 @@ QList<NodeWrapper*> NodeWrapper::predecessors(int type) const
 QList<NodeWrapper*> NodeWrapper::successors() const
 {
     QSet<NodeWrapper*> successors;
-    for (const auto &edge : m_node->outEdges()) {
+    const auto outEdges = m_node->outEdges();
+    for (const auto &edge : outEdges) {
         if (edge->type()->direction() == EdgeType::Unidirectional) {
             successors.insert(m_documentWrapper->nodeWrapper(edge->to()));
             continue;
@@ -324,7 +327,8 @@ QList<NodeWrapper*> NodeWrapper::successors() const
 QList<NodeWrapper*> NodeWrapper::successors(int type) const
 {
     EdgeTypePtr typePtr;
-    for (const auto &typeTest : m_node->document()->edgeTypes()) {
+    const auto edgeTypes = m_node->document()->edgeTypes();
+    for (const auto &typeTest : edgeTypes) {
         if (typeTest->id() == type) {
             typePtr = typeTest;
             break;
@@ -332,11 +336,12 @@ QList<NodeWrapper*> NodeWrapper::successors(int type) const
     }
     if (!typePtr) {
         QString command = QString("node.successors(%1)").arg(type);
-        emit message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
+        Q_EMIT message(i18nc("@info:shell", "%1: edge type ID %2 not registered", command, type), Kernel::ErrorMessage);
         return QList<NodeWrapper*>();
     }
     QSet<NodeWrapper*> successors;
-    for (const auto &edge : m_node->outEdges(typePtr)) {
+    const auto outEdges = m_node->outEdges(typePtr);
+    for (const auto &edge : outEdges) {
         if (edge->type()->direction() == EdgeType::Unidirectional) {
             successors.insert(m_documentWrapper->nodeWrapper(edge->to()));
             continue;
@@ -440,7 +445,8 @@ bool NodeWrapper::event(QEvent *e)
 
 void NodeWrapper::updateDynamicProperties()
 {
-    for (const auto &property : m_node->dynamicProperties()) {
+    const auto dynamicProperties = m_node->dynamicProperties();
+    for (const auto &property : dynamicProperties) {
         // property value must not be set to QVariant::Invalid, else the properties are not accessible
         // from the script engine
         if (m_node->dynamicProperty(property).isValid()) {
