@@ -1,21 +1,7 @@
 /*
- *  Copyright 2011-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
+ *  SPDX-FileCopyrightText: 2011-2014 Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) version 3, or any
- *  later version accepted by the membership of KDE e.V. (or its
- *  successor approved by the membership of KDE e.V.), which shall
- *  act as a proxy defined in Section 6 of version 3 of the license.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef TOPOLOGY_H
@@ -50,7 +36,7 @@ public:
      * \param nodeList is the list of all nodes
      * \return void
      */
-    static void applyMinCutTreeAlignment(NodeList nodes);
+    static void applyMinCutTreeAlignment(const NodeList &nodes);
 
     /** \brief applies Circle topology to node set
      *
@@ -62,7 +48,7 @@ public:
      * \param radius to optionally specify target radius
      * \return void
      */
-    static void applyCircleAlignment(NodeList nodes, qreal radius=0);
+    static void applyCircleAlignment(const NodeList &nodes, qreal radius=0);
 
     /** \brief applies a default topology for undirected graphs
      *
