@@ -87,7 +87,8 @@ MainWindow::MainWindow()
     // disable save action from kpart, since we take care for the editor by global save action
     // here "file_save" is the action identifier from katepartui.rc
     // note that we may not use that name for our own actions
-    foreach(KActionCollection *ac, KActionCollection::allCollections()) {
+    const auto allCollections = KActionCollection::allCollections();
+    for (KActionCollection *ac : allCollections) {
         if (ac->action("file_save")) {
             ac->action("file_save")->setDisabled(true);
         }
@@ -250,7 +251,7 @@ void MainWindow::setProject(Project *project)
     connect(project, &Project::modifiedChanged,
         this, &MainWindow::updateCaption);
     m_currentProject = project;
-    emit graphDocumentChanged(m_currentProject->activeGraphDocument());
+    Q_EMIT graphDocumentChanged(m_currentProject->activeGraphDocument());
 }
 
 void MainWindow::setupActions()
@@ -274,7 +275,7 @@ void MainWindow::setupActions()
     actionCollection()->setDefaultShortcut(projectSaveAction, QKeySequence::Save);
     connect(projectSaveAction, &QAction::triggered, this, &MainWindow::saveProject);
 
-    QAction *projectOpenAction = new QAction(QIcon::fromTheme("document-open"), i18nc("@action:inmenu", "Open Project"), this);
+    QAction *projectOpenAction = new QAction(QIcon::fromTheme("document-open"), i18nc("@action:inmenu", "Open Project..."), this);
     projectOpenAction->setShortcutContext(Qt::ApplicationShortcut);
     actionCollection()->addAction("open-project", projectOpenAction);
     actionCollection()->setDefaultShortcut(projectOpenAction, QKeySequence::Open);
@@ -286,13 +287,13 @@ void MainWindow::setupActions()
     actionCollection()->addAction("recent-project", m_recentProjects);
     m_recentProjects->loadEntries(Settings::self()->config()->group("RecentFiles"));
 
-    createAction("document-save-as",     i18nc("@action:inmenu", "Save Project as"),   "save-project-as",    SLOT(saveProjectAs()), this);
+    createAction("document-save-as",     i18nc("@action:inmenu", "Save Project As..."),   "save-project-as",    SLOT(saveProjectAs()), this);
     createAction("document-new",        i18nc("@action:inmenu", "New Graph Document"), "new-graph",         SLOT(createGraphDocument()), this);
-    createAction("document-new",        i18nc("@action:inmenu", "New Script File"),    "new-script",        SLOT(tryToCreateCodeDocument()),    this);
-    createAction("document-import",     i18nc("@action:inmenu", "Import Graph"),       "import-graph",      SLOT(importGraphDocument()),   this);
-    createAction("document-export",     i18nc("@action:inmenu", "Export Graph as"),    "export-graph-as",      SLOT(exportGraphDocument()), this);
-    createAction("document-import",  i18nc("@action:inmenu", "Import Script"),       "add-script",          SLOT(importCodeDocument()),   this);
-    createAction("document-export", i18nc("@action:inmenu", "Export Script"),      "export-script",      SLOT(exportCodeDocument()), this);
+    createAction("document-new",        i18nc("@action:inmenu", "New Script File..."),    "new-script",        SLOT(tryToCreateCodeDocument()),    this);
+    createAction("document-import",     i18nc("@action:inmenu", "Import Graph..."),       "import-graph",      SLOT(importGraphDocument()),   this);
+    createAction("document-export",     i18nc("@action:inmenu", "Export Graph As..."),    "export-graph-as",      SLOT(exportGraphDocument()), this);
+    createAction("document-import",  i18nc("@action:inmenu", "Import Script..."),       "add-script",          SLOT(importCodeDocument()),   this);
+    createAction("document-export", i18nc("@action:inmenu", "Export Script..."),      "export-script",      SLOT(exportCodeDocument()), this);
 }
 
 void MainWindow::createAction(const QByteArray& iconName, const QString& actionTitle, const QString& actionName,
